/*
** iplog.h - data used by all iplog modules.
** Copyright (C) 1999 Odin <odin@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
*/

#ifndef __COMMON_H
#define __COMMON_H

#define PRIORITY LOG_INFO

#define xfree(x) free(x), (x) = NULL
#define HASH(x, y) ((((x) >> 24) + ((x) >> 16)) & ((y) - 1))

typedef enum {
	FALSE = 0, false = 0,
	TRUE = 1, true = 1
} bool;

struct generic_data {
	struct generic_data *next;
};

#ifndef HAVE_DPRINTF
int dprintf(int fd, const char *fmt, ...);
#endif

void *xmalloc(size_t size);
void *xcalloc(size_t nmemb, size_t size);
char *xstrdup(const char *s);
char *xstrncpy(char *dest, const char *src, size_t n);
char *xstrncat(char *dest, const char *src, size_t n);
void fork_to_back(void);
u_char *serv_lookup(u_short port, const u_char *proto, u_char *buf, size_t len);
u_char *proto_lookup(int proto, u_char *buf, size_t len);
void drop_privs(const u_char *user, const u_char *group);
bool valid_number(const u_char *p);
void fatal(const u_char *fmt, ...);
int get_line(FILE *fp, u_char *buf, size_t len);

void *list_append(const void *data, void **head_ptr, size_t len);
void *list_prepend(const void *data, void **head_ptr, size_t len);
void *list_delete(void *node, void **head_ptr);
void list_destroy(void *list_head, void (*cleanup)(void *));

__inline__ bool tcp_res(void);
__inline__ bool udp_res(void);
__inline__ bool icmp_res(void);

void mysyslog(int pri, const char *fmt, ...);
void myopenlog(const char *name, int option, int facility);
void mycloselog(void);
void get_options(int argc, char * const argv[]);

void expire_portscan(void);

void write_lockfile(void);
void kill_iplog(int sig);

bool is_listening(int port);
void *get_ident_data(void *data);

#define __FAVOR_BSD
#include <netinet/in_systm.h>
#include <netinet/in.h>
#include <netinet/ip.h>
#include <netinet/tcp.h>
#include <arpa/inet.h>

#include <netinet/udp.h>

int tcp_parser(struct ip *ip);
int udp_parser(struct ip *ip);
int icmp_parser(struct ip *ip);
bool portscan(const struct in_addr *in);

u_char *inet_ntoa_r(struct in_addr *in, u_char *buf, size_t len);
u_char *host_lookup(struct in_addr *in, bool resolv, u_char *buf, size_t len);
u_char *_host_lookup(struct in_addr *in, u_char *buf, size_t len);

void expire_dns(void);
void end_smurf_mode(void);
bool test_smurf(const struct ip *ip);

#ifndef MIN
#	define MIN(x,y) ((x) < (y) ? (x) : (y))
#endif

#endif

/* vim:ts=4:sw=8:tw=0 */
